# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-09-11 09:31
from __future__ import unicode_literals

from django.db import migrations
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp', '0002_auto_20190906_0642'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ldpsource',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True),
        ),
    ]
